@@ -131,7 +131,7 @@ class TestIsNA:
         [
             np.arange(4, dtype=float),
             [0.0, 1.0, 0.0, 1.0],
-            Series(list("abcd"), dtype=object),
+            Series(list("abcd")),
             date_range("2020-01-01", periods=4),
         ],
     )
