@@ -34,17 +34,18 @@ def test_hash_error(index):
 
 def test_mutability(index):
     if not len(index):
-        return
+        pytest.skip("Test doesn't make sense for empty index")
     msg = "Index does not support mutable operations"
     with pytest.raises(TypeError, match=msg):
         index[0] = index[0]
 
 
+@pytest.mark.filterwarnings(r"ignore:PeriodDtype\[B\] is deprecated:FutureWarning")
 def test_map_identity_mapping(index, request):
     # GH#12766
 
     result = index.map(lambda x: x)
-    if index.dtype == object and result.dtype == bool:
+    if index.dtype == object and result.dtype in [bool, "string"]:
         assert (index == result).all()
         # TODO: could work that into the 'exact="equiv"'?
         return  # FIXME: doesn't belong in this file anymore!
